'use strict';

const fs = require('fs');
const path = require('path');

module.exports = function(context) {
    // super hacky way to add a build-time dependency on a Gradle
    // module for publishing to Google Play
    const buildGradlePath =
        path.join(context.opts.projectRoot, 'platforms', 'android', 'build.gradle');
    const buildGradle = fs.readFileSync(buildGradlePath, 'utf8');

    const newCordovaBuildScript = `
buildscript {
    repositories {
        mavenCentral()
    }

    // Switch the Android Gradle plugin version requirement depending on the
    // installed version of Gradle. This dependency is documented at
    // http://tools.android.com/tech-docs/new-build-system/version-compatibility
    // and https://issues.apache.org/jira/browse/CB-8143
    if (gradle.gradleVersion >= "2.2") {
        dependencies {
            classpath 'com.android.tools.build:gradle:1.0.0+'
        }
    } else if (gradle.gradleVersion >= "2.1") {
        dependencies {
            classpath 'com.android.tools.build:gradle:0.14.0+'
        }
    } else {
        dependencies {
            classpath 'com.android.tools.build:gradle:0.12.0+'
        }
    }

    dependencies {
        classpath 'com.github.triplet.gradle:play-publisher:1.1.4'
    }
}
`;

    const newPhonegapBuildScript = `
buildscript {
    repositories {
        mavenCentral()
    }

    // Switch the Android Gradle plugin version requirement depending on the
    // installed version of Gradle. This dependency is documented at
    // http://tools.android.com/tech-docs/new-build-system/version-compatibility
    // and https://issues.apache.org/jira/browse/CB-8143
    dependencies {
        classpath 'com.android.tools.build:gradle:1.5.0'
    }

    dependencies {
        classpath 'com.github.triplet.gradle:play-publisher:1.1.4'
    }
   }
`;

    const alreadyHasNewCordovaBuildScript = buildGradle.indexOf(newCordovaBuildScript) > -1;
    const alreadyHasNewPhonegapBuildScript = buildGradle.indexOf(newPhonegapBuildScript) > -1;
    if (alreadyHasNewCordovaBuildScript || alreadyHasNewPhonegapBuildScript) {
        return;
    }

    const oldCordovaBuildScript = `
buildscript {
    repositories {
        mavenCentral()
    }

    // Switch the Android Gradle plugin version requirement depending on the
    // installed version of Gradle. This dependency is documented at
    // http://tools.android.com/tech-docs/new-build-system/version-compatibility
    // and https://issues.apache.org/jira/browse/CB-8143
    if (gradle.gradleVersion >= "2.2") {
        dependencies {
            classpath 'com.android.tools.build:gradle:1.0.0+'
        }
    } else if (gradle.gradleVersion >= "2.1") {
        dependencies {
            classpath 'com.android.tools.build:gradle:0.14.0+'
        }
    } else {
        dependencies {
            classpath 'com.android.tools.build:gradle:0.12.0+'
        }
    }
}
`;
    const oldCordovaBuildScriptExists = buildGradle.indexOf(oldCordovaBuildScript) > -1;
    const oldPhonegapBuildScript = `
buildscript {
    repositories {
        mavenCentral()
    }

    // Switch the Android Gradle plugin version requirement depending on the
    // installed version of Gradle. This dependency is documented at
    // http://tools.android.com/tech-docs/new-build-system/version-compatibility
    // and https://issues.apache.org/jira/browse/CB-8143
    dependencies {
        classpath 'com.android.tools.build:gradle:1.5.0'
    }
   }
`;
    const oldPhonegapBuildScriptExists = buildGradle.indexOf(oldPhonegapBuildScript) > -1;
    if (!oldCordovaBuildScriptExists && !oldPhonegapBuildScriptExists) {
        console.error(buildGradle);
        throw new Error('Expected old buildscript doesn\'t exist');
    }

    let newBuildGradle;

    if(oldCordovaBuildScriptExists) {
        newBuildGradle = buildGradle.replace(oldCordovaBuildScript, newCordovaBuildScript);

    } else if(oldPhonegapBuildScriptExists) {
        newBuildGradle = buildGradle.replace(oldPhonegapBuildScript, newPhonegapBuildScript);

    } else {
        throw new Error('Should not have reached here if neither old script is present');
    }

    fs.writeFileSync(buildGradlePath, newBuildGradle, 'utf8');
};
